==> gedcomviewer-1.1.0.tar.gz: gedcomviewer-1.1.0/src/MMIglade/src/MMIFamilyRecords.cc <==
// generated 2003/12/14 21:27:17 CET by free@mandrake82.maison.fr
// using glademm V0.6.4
//
// newer (non customized) versions of this file go to MMIFamilyRecords.cc_new

// This file is for your program, I won't touch it again!

#include "config.h"
#include "MMIFamilyRecords.hh"
#include "MMIMenuFamily.hh"
#include <gtk--/box.h>
#include <libgnome/libgnome.h>

MMIFamilyRecords::MMIFamilyRecords(void)
{
  set_label(_("Parents"));
  button_press_event.connect(slot(this, &MMIFamilyRecords::popdown_menu));
}

MMIFamilyRecords::AddSignalHandler_t & MMIFamilyRecords::record_added(void)
{
  return _record_added_signal;
}

MMIFamilyRecords::DeleteSignalHandler_t & MMIFamilyRecords::record_deleted(void)
{
  return _record_deleted_signal;
}

MMIFamilyRecord * MMIFamilyRecords::AddRecord(void)
{
  Gtk::HBox *hbox = manage(new class Gtk::HBox(false, 0));
  MMIFamilyRecord * res = manage(new class MMIFamilyRecord());
  hbox->add(*res);
  _family_records->pages().push_back(Gtk::Notebook_Helpers::TabElem(*hbox,"FamilyRecord"));
  //  show_all();
  return res;
}

void MMIFamilyRecords::DeleteRecord(int page_index)
{
  Gtk::Notebook_Helpers::PageList &pages =_family_records->pages();
  if (page_index < pages.size())
    {
      Gtk::Notebook_Helpers::PageList::iterator page_iter = pages.begin();
      for (int i = 0; i < page_index; i++)
	{
	  page_iter++;
	}
      pages.erase(page_iter);
    }
  return;
}

void MMIFamilyRecords::Clear(void)
{
  _family_records->pages().clear();
  return;
}

MMIFamilyRecords::ReturnHandler_t MMIFamilyRecords::popdown_menu(GdkEventButton * event)
{
  if (event->button == 3)
    {
      MMIMenuFamily * popup_menu = manage(new MMIMenuFamily());
      popup_menu->getAddItem()->activate.connect(slot(this, &MMIFamilyRecords::menu_add_activated));
      popup_menu->getDeleteItem()->activate.connect(slot(this, &MMIFamilyRecords::menu_delete_activated));
      guint button = 3;
      guint32 activate_time = 0;
      popup_menu->popup(button, activate_time);
    }
  return 1;
}

void MMIFamilyRecords::menu_add_activated(void)
{
  AddRecord();
  _record_added_signal.emit();
}

void MMIFamilyRecords::menu_delete_activated(void)
{
  int deleted_page_num = _family_records->get_current_page_num();
  if (deleted_page_num > -1)
    {
      DeleteRecord(deleted_page_num);
      _record_deleted_signal.emit(deleted_page_num);
    }
}


void MMIFamilyRecords::ActivateLastPage(void)
{
  _family_records->set_page(-1);
  return;
}

==> gedcomviewer-1.1.1.tar.gz: gedcomviewer-1.1.1/src/MMIglade/src/MMIFamilyRecords.cc <==
// generated 2003/12/14 21:27:17 CET by free@mandrake82.maison.fr
// using glademm V0.6.4
//
// newer (non customized) versions of this file go to MMIFamilyRecords.cc_new

// This file is for your program, I won't touch it again!

#include "config.h"
#include "MMIFamilyRecords.hh"
#include "MMIMenuFamily.hh"
#include <gtk--/box.h>
#include <libgnome/libgnome.h>

MMIFamilyRecords::MMIFamilyRecords(void)
{
  set_label(_("Parents"));
  button_press_event.connect(slot(this, &MMIFamilyRecords::popdown_menu));
}

MMIFamilyRecords::AddSignalHandler_t & MMIFamilyRecords::record_added(void)
{
  return _record_added_signal;
}

MMIFamilyRecords::DeleteSignalHandler_t & MMIFamilyRecords::record_deleted(void)
{
  return _record_deleted_signal;
}

MMIFamilyRecord * MMIFamilyRecords::AddRecord(void)
{
  Gtk::HBox *hbox = manage(new class Gtk::HBox(false, 0));
  MMIFamilyRecord * res = manage(new class MMIFamilyRecord());
  hbox->add(*res);
  _family_records->pages().push_back(Gtk::Notebook_Helpers::TabElem(*hbox,_("FamilyRecord")));
  //  show_all();
  return res;
}

void MMIFamilyRecords::DeleteRecord(int page_index)
{
  Gtk::Notebook_Helpers::PageList &pages =_family_records->pages();
  if (page_index < pages.size())
    {
      Gtk::Notebook_Helpers::PageList::iterator page_iter = pages.begin();
      for (int i = 0; i < page_index; i++)
	{
	  page_iter++;
	}
      pages.erase(page_iter);
    }
  return;
}

void MMIFamilyRecords::Clear(void)
{
  _family_records->pages().clear();
  return;
}

MMIFamilyRecords::ReturnHandler_t MMIFamilyRecords::popdown_menu(GdkEventButton * event)
{
  if (event->button == 3)
    {
      MMIMenuFamily * popup_menu = manage(new MMIMenuFamily());
      popup_menu->getAddItem()->activate.connect(slot(this, &MMIFamilyRecords::menu_add_activated));
      popup_menu->getDeleteItem()->activate.connect(slot(this, &MMIFamilyRecords::menu_delete_activated));
      guint button = 3;
      guint32 activate_time = 0;
      popup_menu->popup(button, activate_time);
    }
  return 1;
}

void MMIFamilyRecords::menu_add_activated(void)
{
  AddRecord();
  _record_added_signal.emit();
}

void MMIFamilyRecords::menu_delete_activated(void)
{
  int deleted_page_num = _family_records->get_current_page_num();
  if (deleted_page_num > -1)
    {
      DeleteRecord(deleted_page_num);
      _record_deleted_signal.emit(deleted_page_num);
    }
}


void MMIFamilyRecords::ActivateLastPage(void)
{
  _family_records->set_page(-1);
  return;
}
